==> kdenlive-0.7.3.tar.gz: kdenlive-0.7.3/src/dvdwizard.h <==
/***************************************************************************
 *   Copyright (C) 2008 by Jean-Baptiste Mardelle (jb@kdenlive.org)        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
 ***************************************************************************/


#ifndef DVDWIZARD_H
#define DVDWIZARD_H

#include <QWizard>
#include <QVBoxLayout>
#include <QItemDelegate>
#include <QPainter>
#include <QProcess>


#include <KDebug>
#include <KTemporaryFile>

#include "dvdwizardvob.h"
#include "dvdwizardmenu.h"
#include "ui_dvdwizardiso_ui.h"
#include "ui_dvdwizardstatus_ui.h"

class DvdWizard : public QWizard
{
    Q_OBJECT
public:
    explicit DvdWizard(const QString &url = QString(), const QString &profile = "dv_pal", QWidget * parent = 0);
    virtual ~DvdWizard();

private:
    DvdWizardVob *m_pageVob;
    DvdWizardMenu *m_pageMenu;
    Ui::DvdWizardIso_UI m_iso;
    Ui::DvdWizardStatus_UI m_status;
    KTemporaryFile m_menuFile;
    KTemporaryFile m_authorFile;
    QProcess *m_dvdauthor;
    QProcess *m_mkiso;
    QString m_creationLog;
    void cleanup();

private slots:
    void slotPageChanged(int page);
    void slotRenderFinished(int exitCode, QProcess::ExitStatus status);
    void slotIsoFinished(int exitCode, QProcess::ExitStatus status);
    void generateDvd();
};

#endif

==> kdenlive-0.7.7.1.tar.gz: kdenlive-0.7.7.1/src/dvdwizard.h <==
/***************************************************************************
 *   Copyright (C) 2008 by Jean-Baptiste Mardelle (jb@kdenlive.org)        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
 ***************************************************************************/


#ifndef DVDWIZARD_H
#define DVDWIZARD_H

#include <QWizard>
#include <QVBoxLayout>
#include <QItemDelegate>
#include <QPainter>
#include <QProcess>


#include <KDebug>
#include <KTemporaryFile>

#include "dvdwizardvob.h"
#include "dvdwizardmenu.h"
#include "dvdwizardchapters.h"
#include "ui_dvdwizardstatus_ui.h"
#include "ui_dvdwizardchapters_ui.h"

class DvdWizard : public QWizard
{
    Q_OBJECT
public:
    explicit DvdWizard(const QString &url = QString(), const QString &profile = "dv_pal", QWidget * parent = 0);
    virtual ~DvdWizard();

private:
    DvdWizardVob *m_pageVob;
    DvdWizardMenu *m_pageMenu;
    Ui::DvdWizardStatus_UI m_status;
    DvdWizardChapters *m_pageChapters;
    KTemporaryFile m_authorFile;
    KTemporaryFile m_menuFile;
    QProcess *m_dvdauthor;
    QProcess *m_mkiso;
    QString m_creationLog;
    void cleanup();
    QMenu *m_burnMenu;

private slots:
    void slotPageChanged(int page);
    void slotRenderFinished(int exitCode, QProcess::ExitStatus status);
    void slotIsoFinished(int exitCode, QProcess::ExitStatus status);
    void generateDvd();
    void slotPreview();
    void slotBurn();
    void slotGenerate();
    void slotAbort();
    void slotLoad();
    void slotSave();
    void slotShowRenderInfo();
    void slotShowIsoInfo();
};

#endif
